************
django-unis3
************

Abstract
####################

S3 Django Storage.
Wrapper to the s3-local-endpoint library.

.. image:: https://img.shields.io/pypi/v/django-unis3.svg
   :target: https://pypi.python.org/pypi/django-unis3
   :alt: pypi version

.. image:: https://git.unistra.fr/di/cesar/django-unis3/badges/develop/pipeline.svg
   :target: https://git.unistra.fr/di/cesar/django-unis3/pipelines
   :alt: develop branch pipeline

.. image:: https://git.unistra.fr/di/cesar/django-unis3/badges/develop/coverage.svg
   :target: https://git.unistra.fr/di/cesar/django-unis3/commits/develop
   :alt: develop branch coverage
